-- AtlasLoot_Classes

-- loot.lua:
-- Loot tables for AtlasLoot_Classes data

local addonName, addonTable = ...

local AtlasLoot = _G.AtlasLoot

--if we are running with AtlasLoot before v8, cancel
if AtlasLoot and ATLASLOOT_VERSION_NUM then
	return
end

local data = AtlasLoot.ItemDB:Add(addonName)

local HORDE_RACIAL_DIFF = data:AddDifficulty("|cFFBB4444Horde")
local ALLIANCE_RACIAL_DIFF = data:AddDifficulty("|cFF4444BBAlliance")
local NEUTRAL_RACIAL_DIFF = data:AddDifficulty("|cFFBBBB44Neutral")
local DK_DIFF = data:AddDifficulty("Death Knight")
local DRUID_DIFF = data:AddDifficulty("Druid")
local HUNTER_DIFF = data:AddDifficulty("Hunter")
local MAGE_DIFF = data:AddDifficulty("Mage")
local MONK_DIFF = data:AddDifficulty("Monk")
local PALADIN_DIFF = data:AddDifficulty("Paladin")
local PRIEST_DIFF = data:AddDifficulty("Priest")
local ROGUE_DIFF = data:AddDifficulty("Rogue")
local SHAMAN_DIFF = data:AddDifficulty("Shaman")
local WARLOCK_DIFF = data:AddDifficulty("Warlock")
local WARRIOR_DIFF = data:AddDifficulty("Warrior")

local SPELL_ITTYPE = data:AddItemTableType("ClassesSpell")

local CLASSES_CONTENT = data:AddContentType("Classes", {0.0, 0.0, 0.0, 1})
local RACIAL_CONTENT = data:AddContentType("Races", {0.0, 0.0, 0.0, 1})

local MASTERY = "|cFF1144FFMastery"
local EMPOWERED = "|cFF11FF44Empowered"
local function colorstr(class) return "|c"..RAID_CLASS_COLORS[class].colorStr end

local FACTION_INFO_IS_SET_ID = 998
local IGNORE_THIS_BUTTON_ID = 999

data["CLASS_DK"] = {
	name = "Death Knight",
	ContentType = CLASSES_CONTENT,
	TableType = SPELL_ITTYPE,
	items = {
		{
			name = "Blood",
			CoinTexture = "texture:Interface\\Icons\\spell_deathknight_bloodpresence",
			[DK_DIFF] = {
				{ 1, { id = 82246, level = 1 }, },
				{ 2, { id = 161608, level = 10 }, },
				{ 3, { id = 81136, level = 10 }, },
				{ 4, { id = 158298, level = 10 }, },
				{ 5, { id = 50842, level = 55 }, },
				{ 6, { id = 50034, level = 55 }, },
				{ 7, { id = 47541, level = 55 }, },
				{ 8, { id = 50977, level = 55 }, },
				{ 9, { id = 49576, level = 55 }, },
				{ 10, { id = 48266, level = 55 }, },
				{ 11, { id = 45477, level = 55 }, },
				{ 12, { id = 45462, level = 55 }, },
				{ 13, { id = 53428, level = 55 }, },
				{ 14, { id = 50029, level = 55 }, },
				{ 15, { id = 49998, level = 56 }, },
				{ 16, { id = 48263, level = 57 }, },
				{ 17, { id = 47528, level = 57 }, },
				{ 18, { id = 45524, level = 58 }, },
				{ 19, { id = 56222, level = 58 }, },
				{ 20, { id = 47476, level = 58 }, },
				{ 21, { id = 178819, level = 60 }, },
				{ 22, { id = 43265, level = 60 }, },
				{ 23, { id = 51986, level = 61 }, },
				{ 24, { id = 48792, level = 62 }, },
				{ 25, { id = 50371, level = 64 }, },
				{ 26, { id = 48982, level = 64 }, },
				{ 27, { id = 48265, level = 64 }, },
				{ 28, { id = 57330, level = 65 }, },
				{ 29, { id = 3714, level = 66 }, },
				{ 30, { id = 48707, level = 68 }, },
				{ 101, { id = 111673, level = 69 }, },
				{ 102, { id = 81164, level = 70 }, },
				{ 103, { id = 61999, level = 72 }, },
				{ 104, { id = 81127, level = 72 }, },
				{ 105, { id = 49028, level = 74 }, },
				{ 106, { id = 47568, level = 76 }, },
				{ 107, { id = 161797, level = 76 }, },
				{ 108, { id = 55233, level = 76 }, },
				{ 109, { id = 49222, level = 78 }, },
				{ 110, { id = 42650, level = 80 }, },
				{ 111, { id = 77513, level = 80, rank = MASTERY }, },
				{ 112, { id = 155522, level = 80 }, },
				{ 113, { id = 77575, level = 81 }, },
				{ 114, { id = 77606, level = 85 }, },
				{ 115, { id = 130736, level = 87 }, },
				{ 116, { id = 114866, level = 87 }, },
				{ 117, { id = 165394, level = 90 }, },
				{ 118, { id = 157338, level = "92+", rank = EMPOWERED }, },
				{ 119, { id = 157343, level = "92+", rank = EMPOWERED }, },
				{ 120, { id = 157337, level = "92+", rank = EMPOWERED }, },
				{ 121, { id = 157336, level = "92+", rank = EMPOWERED }, },
			},
		},
		{
			name = "Frost",
			CoinTexture = "texture:Interface\\Icons\\spell_deathknight_frostpresence",
			[DK_DIFF] = {
				{ 1, { id = 674, level = "1" }, },
				{ 2, { id = 82246, level = "1" }, },
				{ 3, { id = 59057, level = "10" }, },
				{ 4, { id = 50842, level = "55" }, },
				{ 5, { id = 54637, level = "55" }, },
				{ 6, { id = 47541, level = "55" }, },
				{ 7, { id = 50977, level = "55" }, },
				{ 8, { id = 49576, level = "55" }, },
				{ 9, { id = 48266, level = "55" }, },
				{ 10, { id = 49143, level = "55" }, },
				{ 11, { id = 49184, level = "55" }, },
				{ 12, { id = 50887, level = "55" }, },
				{ 13, { id = 45477, level = "55" }, },
				{ 14, { id = 45462, level = "55" }, },
				{ 15, { id = 53428, level = "55" }, },
				{ 16, { id = 49998, level = "56" }, },
				{ 17, { id = 48263, level = "57" }, },
				{ 18, { id = 47528, level = "57" }, },
				{ 19, { id = 45524, level = "58" }, },
				{ 20, { id = 49020, level = "58" }, },
				{ 21, { id = 47476, level = "58" }, },
				{ 22, { id = 178819, level = "60" }, },
				{ 23, { id = 43265, level = "60" }, },
				{ 24, { id = 55610, level = "60" }, },
				{ 25, { id = 51986, level = "61" }, },
				{ 26, { id = 48792, level = "62" }, },
				{ 27, { id = 51128, level = "63" }, },
				{ 28, { id = 48265, level = "64" }, },
				{ 29, { id = 57330, level = "65" }, },
				{ 30, { id = 50385, level = "65" }, },
				{ 101, { id = 3714, level = "66" }, },
				{ 102, { id = 48707, level = "68" }, },
				{ 103, { id = 51271, level = "68" }, },
				{ 104, { id = 111673, level = "69" }, },
				{ 105, { id = 61999, level = "72" }, },
				{ 106, { id = 81333, level = "74" }, },
				{ 107, { id = 66192, level = "74" }, },
				{ 108, { id = 47568, level = "76" }, },
				{ 109, { id = 42650, level = "80" }, },
				{ 110, { id = 77514, level = "80", rank = MASTERY }, },
				{ 111, { id = 77575, level = "81" }, },
				{ 112, { id = 77606, level = "85" }, },
				{ 113, { id = 130736, level = "87" }, },
				{ 114, { id = 130735, level = "87" }, },
				{ 115, { id = 157409, level = "92+", rank = EMPOWERED }, },
				{ 116, { id = 157389, level = "92+", rank = EMPOWERED }, },
				{ 117, { id = 157367, level = "92+", rank = EMPOWERED }, },
				{ 118, { id = 157376, level = "92+", rank = EMPOWERED }, },
			},
		},
    {
      name = "Unholy",
      CoinTexture = "texture:Interface\\Icons\\spell_deathknight_unholypresence",
      [DK_DIFF] = {
        { 1, { id = 82246, level = "1" }, },
        { 2, { id = 51160, level = "10" }, },
        { 3, { id = 56835, level = "10" }, },
        { 4, { id = 50842, level = "55" }, },
        { 5, { id = 47541, level = "55" }, },
        { 6, { id = 50977, level = "55" }, },
        { 7, { id = 49576, level = "55" }, },
        { 8, { id = 48266, level = "55" }, },
        { 9, { id = 45477, level = "55" }, },
        { 10, { id = 45462, level = "55" }, },
        { 11, { id = 53428, level = "55" }, },
        { 12, { id = 91107, level = "55" }, },
        { 13, { id = 49998, level = "56" }, },
        { 14, { id = 46584, level = "56" }, },
        { 15, { id = 48263, level = "57" }, },
        { 16, { id = 47528, level = "57" }, },
        { 17, { id = 45524, level = "58" }, },
        { 18, { id = 55090, level = "58" }, },
        { 19, { id = 47476, level = "58" }, },
        { 20, { id = 178819, level = "60" }, },
        { 21, { id = 43265, level = "60" }, },
        { 22, { id = 49572, level = "60" }, },
        { 23, { id = 55610, level = "60" }, },
        { 24, { id = 51986, level = "61" }, },
        { 25, { id = 85948, level = "62" }, },
        { 26, { id = 48792, level = "62" }, },
        { 27, { id = 49530, level = "64" }, },
        { 28, { id = 48265, level = "64" }, },
        { 29, { id = 57330, level = "65" }, },
        { 30, { id = 3714, level = "66" }, },
        { 101, { id = 48707, level = "68" }, },
        { 102, { id = 111673, level = "69" }, },
        { 103, { id = 63560, level = "70" }, },
        { 104, { id = 61999, level = "72" }, },
        { 105, { id = 49206, level = "74" }, },
        { 106, { id = 50392, level = "75" }, },
        { 107, { id = 47568, level = "76" }, },
        { 108, { id = 42650, level = "80" }, },
        { 109, { id = 77515, level = "80", rank = MASTERY }, },
        { 110, { id = 77575, level = "81" }, },
        { 111, { id = 77606, level = "85" }, },
        { 112, { id = 130736, level = "87" }, },
        { 113, { id = 165395, level = "90" }, },
        { 114, { id = 157441, level = "92+", rank = EMPOWERED }, },
        { 115, { id = 157412, level = "92+", rank = EMPOWERED }, },
        { 116, { id = 157437, level = "92+", rank = EMPOWERED }, },
        { 117, { id = 157342, level = "92+", rank = EMPOWERED }, },
      },
    },
	},
}

data["CLASS_DRUID"] = {
  name = "Druid",
  ContentType = CLASSES_CONTENT,
  TableType = SPELL_ITTYPE,
  items = {
    {
      name = "Balance",
      CoinTexture = "texture:Interface\\Icons\\spell_deathknight_bloodpresence",
      [DRUID_DIFF] = {
        { 1, { id = 82246, level = 1 }, },
      },
    },
  },
}

data["RACIALS"] = {
	name = "Racial Abilities",
	ContentType = RACIAL_CONTENT,
	TableType = SPELL_ITTYPE,
	items = {
		{
			name = "Blood Elf",
			CoinTexture = "texture:Interface\\Icons\\inv_mask_04",
			[HORDE_RACIAL_DIFF] = {
				{ 1, 154742 },
				{ 2, 28877 },
				{ 3, 822 },
				{ 4, 28730 },
				{ 5, { id = 50613, rank = colorstr("DEATHKNIGHT").."Death Knight" }, },
				{ 6, { id = 80483, rank = colorstr("HUNTER").."Hunter" }, },
				{ 7, { id = 129597, rank = colorstr("MONK").."Monk" }, },
				{ 8, { id = 155145, rank = colorstr("PALADIN").."Paladin" }, },
				{ 9, { id = 25046, rank = colorstr("ROGUE").."Rogue" }, },
				{ 10, { id = 69179, rank = colorstr("WARRIOR").."Warrior" }, },
        { 12, 669 },
        { 13, 813 },
			},
		},
    {
      name = "Draenei",
      CoinTexture = "texture:Interface\\Icons\\inv_mask_05",
      [ALLIANCE_RACIAL_DIFF] = {
        { 1, 28875 },
        { 2, 121093 },
        { 3, 6562 },
        { 4, 59221 },
        { 6, 668 },
        { 7, 29932 },
      },
    },
    {
      name = "Dwarf",
      CoinTexture = "texture:Interface\\Icons\\achievement_character_dwarf_male",
      [ALLIANCE_RACIAL_DIFF] = {
        { 1, 92682 },
        { 2, 20596 },
        { 3, 59224 },
        { 4, 20594 },
        { 6, 668 },
        { 7, 672 },
      },
    },
    {
      name = "Gnome",
      CoinTexture = "texture:Interface\\Icons\\achievement_character_gnome_male",
      [ALLIANCE_RACIAL_DIFF] = {
        { 1, 20592 },
        { 2, 20593 },
        { 3, 20589 },
        { 4, 92680 },
        { 5, 20591 },
        { 6, { id = 154744, rank = colorstr("ROGUE").."Rogue" }, },
        { 7, { id = 154747, rank = colorstr("DEATHKNIGHT").."Death Knight" }, },
        { 8, { id = 154746, rank = colorstr("WARRIOR").."Warrior" }, },        
        { 10, 668 },
        { 11, 7340 },
      },
    },
    {
			name = "Goblin",
			CoinTexture = "texture:Interface\\Icons\\inv_mask_10",
			[HORDE_RACIAL_DIFF] = {
				{ 1, 69044 },
				{ 2, 69045 },
				{ 3, 69046 },
				{ 4, 69041 },
				{ 5, 69070 },
				{ 6, 69042 },
        { 8, 669 },
        { 9, 69269 },
			},
		},
    {
      name = "Human",
      CoinTexture = "texture:Interface\\Icons\\achievement_character_human_male",
      [ALLIANCE_RACIAL_DIFF] = {
        { 1, 20599 },
        { 2, 59752 },
        { 3, 20598 },
        { 5, 668 },
      },
    },
    {
      name = "Night Elf",
      CoinTexture = "texture:Interface\\Icons\\achievement_character_nightelf_male",
      [ALLIANCE_RACIAL_DIFF] = {
        { 1, 20583 },
        { 2, 20582 },
        { 3, 58984 },
        { 4, 154748 },
        { 5, 20585 },
        { 7, 668 },
        { 8, 671 },
      },
    },
    {
      name = "Orc",
      CoinTexture = "texture:Interface\\Icons\\achievement_character_orc_male",
      [HORDE_RACIAL_DIFF] = {
        { 1, 20573 },
        { 2, { id = 20572, rank = colorstr("DEATHKNIGHT").."DK "..colorstr("HUNTER").."Hunter "..colorstr("ROGUE").."Rogue "..colorstr("WARRIOR").."Warrior" }, },
        { 3, { id = 33697, rank = colorstr("MONK").."Monk "..colorstr("SHAMAN").."Shaman" }, },
        { 4, { id = 33702, rank = colorstr("MAGE").."Mage "..colorstr("WARLOCK").."Warlock" }, },
        { 6, 669 },
      },
    },
    {
      name = "Pandaren",
      CoinTexture = "texture:Interface\\Icons\\achievement_guild_classypanda",
      [HORDE_RACIAL_DIFF] = {
        { 1, 107076 },
        { 2, 107072 },
        { 3, 107073 },
        { 4, 107074 },
        { 5, 107079 },
        { 7, 669, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 8, 108131, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
      },
      [ALLIANCE_RACIAL_DIFF] = {
        { 1, 107076 },
        { 2, 107072 },
        { 3, 107073 },
        { 4, 107074 },
        { 5, 107079 },
        { 7, 668, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 8, 108130, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
      },
      [NEUTRAL_RACIAL_DIFF] = {
        { 1, 107076 },
        { 2, 107072 },
        { 3, 107073 },
        { 4, 107074 },
        { 5, 107079 },
        { 7, 108127 },
      },
    },
    {
      name = "Tauren",
      CoinTexture = "texture:Interface\\Icons\\achievement_character_tauren_male",
      [HORDE_RACIAL_DIFF] = {
        { 1, 154743 },
        { 2, 20552 },
        { 3, 20550 },
        { 4, 20551 },
        { 5, 20549 },
        { 7, 669 },
        { 8, 670 },
      },
    },
    {
      name = "Troll",
      CoinTexture = "texture:Interface\\Icons\\achievement_character_troll_male",
      [HORDE_RACIAL_DIFF] = {
        { 1, 20557 },
        { 2, 26297 },
        { 3, 58943 },
        { 4, 20555 },
        { 6, 669 },
        { 7, 7341 },
      },
    },
    {
      name = "Undead",
      CoinTexture = "texture:Interface\\Icons\\achievement_character_undead_male",
      [HORDE_RACIAL_DIFF] = {
        { 1, 20577 },
        { 2, 20579 },
        { 3, 5227 },
        { 4, 7744 },
        { 6, 669 },
        { 7, 17737 },
      },
    },
    {
      name = "Worgen",
      CoinTexture = "texture:Interface\\Icons\\inv_mask_08",
      [ALLIANCE_RACIAL_DIFF] = {
        { 1, 68976 },
        { 2, 94293 },
        { 3, 68992 },
        { 4, 68978 },
        { 5, 87840 },
        { 6, 68996 },
        { 7, 68975 },
        { 9, 668 },
        { 10, 69270 },
      },
    },
  },
}

function cmdebug()
  local i=1
  while 1 do
    local skillType, spellId = GetSpellBookItemInfo(i, BOOKTYPE_SPELL)
    local spellName, spellSubName = GetSpellBookItemName(i, BOOKTYPE_SPELL)
    local spellLevel = GetSpellAvailableLevel(i, BOOKTYPE_SPELL)
    if not spellName then break end
    print("{ , { id = "..spellId..", level = "..spellLevel..", name = \""..spellName.."\" }, },")

    i=i+1
  end
end
function cmdebug2(arg)
  print("|T"..arg..":16|t")
end






